Struct google_binaryauthorization1_beta1::Attestor [−][src]
pub struct Attestor {
pub update_time: Option<String>,
pub name: Option<String>,
pub user_owned_drydock_note: Option<UserOwnedDrydockNote>,
pub description: Option<String>,
}An attestor that attests to container image artifacts. An existing attestor cannot be modified except where indicated.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- attestors update projects (request|response)
- attestors create projects (request|response)
- attestors get projects (response)
Fields
update_time: Option<String>
Output only. Time when the attestor was last updated.
name: Option<String>
Required. The resource name, in the format:
projects/*/attestors/*. This field may not be updated.
user_owned_drydock_note: Option<UserOwnedDrydockNote>
A Drydock ATTESTATION_AUTHORITY Note, created by the user.
description: Option<String>
Optional. A descriptive comment. This field may be updated. The field may be displayed in chooser dialogs.