Struct google_binaryauthorization1_beta1::AttestorPublicKey [−][src]
pub struct AttestorPublicKey {
pub comment: Option<String>,
pub ascii_armored_pgp_public_key: Option<String>,
pub id: Option<String>,
}An attestator public key that will be used to verify attestations signed by this attestor.
This type is not used in any activity, and only used as part of another schema.
Fields
comment: Option<String>
Optional. A descriptive comment. This field may be updated.
ascii_armored_pgp_public_key: Option<String>
ASCII-armored representation of a PGP public key, as the entire output by
the command gpg --export --armor foo@example.com (either LF or CRLF
line endings).
id: Option<String>
Output only. This field will be overwritten with key ID information, for example, an identifier extracted from a PGP public key. This field may not be updated.